@@ -29,7 +29,10 @@ import {
   IconButton
 } from '@mui/material';
 import Select, { SelectChangeEvent } from '@mui/material/Select';
-import { getAllSubmissions } from '../../../services/submissions.service';
+import {
+  getAllSubmissions,
+  ltiSyncSubmissions
+} from '../../../services/submissions.service';
 import { AgreeDialog } from '../../util/dialog';
 import NavigateNextIcon from '@mui/icons-material/NavigateNext';
 import FileDownloadIcon from '@mui/icons-material/FileDownload';
@@ -48,6 +51,7 @@ import { GlobalObjects } from '../../../index';
 import { enqueueSnackbar } from 'notistack';
 import { loadString, storeString } from '../../../services/storage.service';
 import CloudSyncIcon from '@mui/icons-material/CloudSync';
+import { getConfig } from '../../../services/config.service';
 /**
  * Props for GradingComponent.
  */
@@ -76,6 +80,7 @@ export const GradingComponent = (props: IGradingProps) => {
   );
   const [showDialog, setShowDialog] = React.useState(false);
   const [showLogs, setShowLogs] = React.useState(false);
+  const [showSyncGrades, setSyncGrades] = React.useState(false);
   const [logs, setLogs] = React.useState(undefined);
   const [dialogContent, setDialogContent] = React.useState({
     title: '',
@@ -169,6 +174,13 @@ export const GradingComponent = (props: IGradingProps) => {
     });
     setShowDialog(true);
   };
+
+  const getConfigFromService = () => {
+    getConfig().then(response => {
+      setSyncGrades(response['enable_lti_features']);
+    });
+  };
+
   /**
    * Closes dialog window.
    */
@@ -233,6 +245,7 @@ export const GradingComponent = (props: IGradingProps) => {
 
   React.useEffect(() => {
     updateSubmissions();
+    getConfigFromService();
   }, [option, displayManualGrading]);
   /**
    * Calculates chip color based on submission status.
@@ -387,13 +400,34 @@ export const GradingComponent = (props: IGradingProps) => {
       title: 'LTI Sync Submission',
       message: 'Do you wish to sync Submissions?',
       handleAgree: async () => {
-
-        closeDialog();
+        await ltiSyncSubmissions(props.lecture.id, props.assignment.id)
+          .then(response => {
+            closeDialog();
+            enqueueSnackbar(
+              'Successfully matched ' +
+                response.syncable_users +
+                ' submissions with learning platform',
+              { variant: 'success' }
+            );
+            enqueueSnackbar(
+              'Successfully synced latest submissions with feedback of ' +
+                response.synced_user +
+                ' users',
+              { variant: 'success' }
+            );
+          })
+          .catch(error => {
+            closeDialog();
+            enqueueSnackbar(
+              'Error while trying to sync submissions:' + error.message,
+              { variant: 'error' }
+            );
+          });
       },
       handleDisagree: () => closeDialog()
     });
     setShowDialog(true);
-  }
+  };
 
   return (
     <div>
@@ -517,15 +551,18 @@ export const GradingComponent = (props: IGradingProps) => {
         >
           {`Export ${optionName()} Submissions`}
         </Button>
-        {/*
+
         <Button
           variant="outlined"
           startIcon={<CloudSyncIcon />}
           sx={{ m: 3 }}
-          onClick={handleSyncSubmission}>
-          {'LTI Sync Grades'}
+          disabled={!showSyncGrades}
+          onClick={handleSyncSubmission}
+        >
+          {showSyncGrades
+            ? 'LTI Sync Grades'
+            : 'LTI Sync Grades (disabled by grader service)'}
         </Button>
-        */}
       </span>
 
       <LoadingOverlay
